Installation
============

```bash
pip install itemset-mining
```

Note that the latest version of the library
will only work toward being compatible with newer version of Python.
This is to reduce the technical debt of maintaining the project and Python itself.
The support policty will roughly follow Numpy's community version support recommendation in [NEP 29](https://numpy.org/neps/nep-0029-deprecation_policy.html). See the table below for officially supported versions:

| Bulwark | Python |
|:-------:|:------:|
|  0.1.0  |  >=3.6 |
